ntrfc.turbo.airfoil\_generators package
=======================================

Submodules
----------

ntrfc.turbo.airfoil\_generators.naca\_airfoil\_creator module
-------------------------------------------------------------

.. automodule:: ntrfc.turbo.airfoil_generators.naca_airfoil_creator
   :members:
   :undoc-members:
   :show-inheritance:

ntrfc.turbo.airfoil\_generators.parsec\_airfoil\_creator module
---------------------------------------------------------------

.. automodule:: ntrfc.turbo.airfoil_generators.parsec_airfoil_creator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ntrfc.turbo.airfoil_generators
   :members:
   :undoc-members:
   :show-inheritance:
